@@ -1,11 +1,13 @@
-import contextlib
-import panel as pn
-import os
 import ast
+import contextlib
 import logging
+import os
 import re
+
+import panel as pn
+
+from .core import OpenFile, get_filesystem_class, split_protocol
 from .registry import known_implementations
-from .core import split_protocol, get_filesystem_class, OpenFile
 
 pn.extension()
 logger = logging.getLogger("fsspec.gui")
@@ -36,8 +38,7 @@ class SigSlot(object):
         self._setup()
 
     def _setup(self):
-        """Create GUI elements and register signals
-        """
+        """Create GUI elements and register signals"""
         self.panel = pn.pane.PaneBase()
         # no signals to set up in the base class
 
