@@ -1,8 +1,9 @@
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function
 
 import zipfile
+
 from fsspec import AbstractFileSystem, open_files
-from fsspec.utils import tokenize, DEFAULT_BLOCK_SIZE
+from fsspec.utils import DEFAULT_BLOCK_SIZE, tokenize
 
 
 class ZipFileSystem(AbstractFileSystem):
@@ -22,7 +23,7 @@ class ZipFileSystem(AbstractFileSystem):
         target_protocol=None,
         target_options=None,
         block_size=DEFAULT_BLOCK_SIZE,
-        **kwargs
+        **kwargs,
     ):
         """
         Parameters
@@ -124,7 +125,7 @@ class ZipFileSystem(AbstractFileSystem):
         block_size=None,
         autocommit=True,
         cache_options=None,
-        **kwargs
+        **kwargs,
     ):
         path = self._strip_protocol(path)
         if mode != "rb":
