@@ -4,13 +4,19 @@ import os
 import warnings
 from distutils.version import LooseVersion
 from errno import ESPIPE
-from hashlib import sha256
 from glob import has_magic
+from hashlib import sha256
 
+from .config import apply_config
 from .dircache import DirCache
 from .transaction import Transaction
-from .utils import read_block, tokenize, stringify_path, other_paths
-from .config import apply_config
+from .utils import (
+    get_package_version_without_import,
+    other_paths,
+    read_block,
+    stringify_path,
+    tokenize,
+)
 
 logger = logging.getLogger("fsspec")
 
@@ -72,16 +78,17 @@ class _Cached(type):
             return obj
 
 
-try:  # optionally derive from pyarrow's FileSystem, if available
-    import pyarrow as pa
-except ImportError:
-    up = object
-else:
-    # only derive from the legacy pyarrow's FileSystem for older pyarrow versions
-    if LooseVersion(pa.__version__) < LooseVersion("2.0"):
+pa_version = get_package_version_without_import("pyarrow")
+if pa_version and LooseVersion(pa_version) < LooseVersion("2.0"):
+    try:
+        import pyarrow as pa
+
         up = pa.filesystem.DaskFileSystem
-    else:
+    except ImportError:  # pragma: no cover
+        # pyarrow exists but doesn't import for some reason
         up = object
+else:  # pragma: no cover
+    up = object
 
 
 class AbstractFileSystem(up, metaclass=_Cached):
@@ -424,7 +431,7 @@ class AbstractFileSystem(up, metaclass=_Cached):
         path = self._strip_protocol(path)
         out = dict()
         detail = kwargs.pop("detail", False)
-        for path, dirs, files in self.walk(path, maxdepth, detail=True, **kwargs):
+        for _, dirs, files in self.walk(path, maxdepth, detail=True, **kwargs):
             if withdirs:
                 files.update(dirs)
             out.update({info["name"]: info for name, info in files.items()})
@@ -747,7 +754,7 @@ class AbstractFileSystem(up, metaclass=_Cached):
 
         Calls put_file for each source.
         """
-        from .implementations.local import make_path_posix, LocalFileSystem
+        from .implementations.local import LocalFileSystem, make_path_posix
 
         rpath = (
             self._strip_protocol(rpath)
@@ -879,7 +886,7 @@ class AbstractFileSystem(up, metaclass=_Cached):
         block_size=None,
         autocommit=True,
         cache_options=None,
-        **kwargs
+        **kwargs,
     ):
         """Return raw bytes-mode file-like from the file-system"""
         return AbstractBufferedFile(
@@ -889,7 +896,7 @@ class AbstractFileSystem(up, metaclass=_Cached):
             block_size,
             autocommit,
             cache_options=cache_options,
-            **kwargs
+            **kwargs,
         )
 
     def open(self, path, mode="rb", block_size=None, cache_options=None, **kwargs):
@@ -933,9 +940,9 @@ class AbstractFileSystem(up, metaclass=_Cached):
                 block_size=block_size,
                 autocommit=ac,
                 cache_options=cache_options,
-                **kwargs
+                **kwargs,
             )
-            if not ac:
+            if not ac and "r" not in mode:
                 self.transaction.files.append(f)
             return f
 
@@ -1028,7 +1035,7 @@ class AbstractFileSystem(up, metaclass=_Cached):
         return json.dumps(
             dict(
                 **{"cls": cls, "protocol": proto, "args": self.storage_args},
-                **self.storage_options
+                **self.storage_options,
             )
         )
 
@@ -1047,9 +1054,10 @@ class AbstractFileSystem(up, metaclass=_Cached):
         -------
         file system instance, not necessarily of this particular class.
         """
-        from .registry import _import_class, get_filesystem_class
         import json
 
+        from .registry import _import_class, get_filesystem_class
+
         dic = json.loads(blob)
         protocol = dic.pop("protocol")
         try:
@@ -1197,7 +1205,7 @@ class AbstractBufferedFile(io.IOBase):
         autocommit=True,
         cache_type="readahead",
         cache_options=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Template for files with buffered reading and writing
